fnss.traffic.eventscheduling.EventSchedule.events_between — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.traffic.eventscheduling.EventSchedule.events_between

`EventSchedule.` `events_between`(t_start, t_end)

  Return an event schedule comprising all events scheduled between a start time (included) and an end time (excluded).

  Parameters : | t_start : float The start time t_end : float The end time
  Returns : | event_schedule : EventSchedule An EventSchedule object

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »